@@ -3,7 +3,7 @@ from typing import ClassVar
 from pydantic import BaseModel, Field
 from tygle_docs.types.responses import ReplaceAllTextResponse
 
-from .update_request import UpdateRequest
+from .update_request import UpdateRequestBody
 
 
 class SubstringMatchCriteria(BaseModel):
@@ -11,11 +11,9 @@ class SubstringMatchCriteria(BaseModel):
     match_case: bool = Field(alias="matchCase")
 
 
-class ReplaceAllText(BaseModel):
+class ReplaceAllText(UpdateRequestBody):
+    response_type: ClassVar = ReplaceAllTextResponse
+    key: ClassVar = "replaceAllText"
+
     replace_text: str = Field(alias="replaceText")
     contains_text: SubstringMatchCriteria = Field(alias="containsText")
-
-
-class ReplaceAllTextRequest(UpdateRequest):
-    response_type: ClassVar = ReplaceAllTextResponse
-    replace_all_text: ReplaceAllText = Field(alias="replaceAllText")
